pype32.pype32.FileHeader

Package pype32 :: Module pype32 :: Class FileHeader |
[hide private]
[frames] | no frames]

# Class FileHeader

source code

                     object --+
                              |
    baseclasses.BaseStructClass --+
                                  |
                                 FileHeader

FileHeader object.

Instance Methods | [hide private]
__init__(self, shouldPack=True) Class representation of the `IMAGE_FILE_HEADER` structure. | source code
getType(self) Returns consts.IMAGE_FILE_HEADER. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Inherited from baseclasses.BaseStructClass
__len__(self) | source code
__str__(self) str(x) | source code
dict |
getFields(self) Returns all the class attributues. | source code
sizeof(self) | source code

Static Methods | [hide private]
FileHeader |
parse(readDataInstance) Returns a new FileHeader object. | source code

Instance Variables | [hide private]
| machine WORD machine.
| numberOfSections WORD numberOfSections.
| timeDateStamp DWORD timeDataStamp.
| pointerToSymbolTable DWORD pointerToSymbolTable.
| numberOfSymbols DWORD numberOfSymbols.
| sizeOfOptionalHeader WORD sizeOfOptionalHeader.
| characteristics WORD characteristics.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
Class representation of the `IMAGE_FILE_HEADER` structure. Parameters: `shouldPack` (bool) - (Optional) If set to `True`, the object will be packed. If set to `False`, the object won't be packed. Overrides: object.__init__ See Also: http://msdn.microsoft.com/es-es/library/windows/desktop/ms680313%28v=vs.85%29.aspx

### parse(readDataInstance) Static Method | source code
Returns a new FileHeader object. Parameters: `readDataInstance` (ReadData) - A ReadData object with data to be parsed as a FileHeader object. Returns: FileHeader A new ReadData object.

### getType(self) | source code
Returns consts.IMAGE_FILE_HEADER. Raises: `NotImplementedError` - The method wasn't implemented in the inherited class. Overrides: baseclasses.BaseStructClass.getType